@@ -15,18 +15,13 @@
 from falcon import testing
 from mock import mock
 
-from monasca_log_api.api.core import request
-from monasca_log_api.reference.common import validation
+from monasca_log_api.app.base import request
+from monasca_log_api.app.base import validation
 from monasca_log_api.tests import base
 
 
 class TestRequest(base.BaseTestCase):
 
-    def setUp(self):
-        super(TestRequest, self).setUp()
-        base.mock_config(self)
-        base.mock_context(self)
-
     def test_use_context_from_request(self):
         req = request.Request(
             testing.create_environ(
